#!/usr/bin/env python

"""
	Kumblr is developed by Peppe Bergqvist <p@bergqvi.st>

	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
"""

import sys
from PyQt4.QtCore import *
from PyQt4.QtGui import *

from pytumblr import *
import icons_rc


class App(QApplication):
	def __init__(self, argv):
		QApplication.__init__(self, argv)
	
		self.setupUi()
		self.setupTumblr()
		
	def setupTumblr(self):
		settings = QSettings("Kumblr", "Kumblr")

		settings.beginGroup("Account")
		self.username = settings.value("username").toString()
		self.email = settings.value("email").toString()
		self.password = settings.value("password").toString()
		
		if len(self.username) == 0 or len(self.email) == 0 or len(self.password) == 0:
			QMessageBox.warning(None, "Kumblr", "You have to fill in all the fields")
			self.setupAccount()
		else:
			self.tumblr = pytumblr(self.username, self.email,  self.password)
			self.tumblrAuth = self.tumblr.auth()
			if self.tumblrAuth == "< Authenticated! >":
				print "logon!"
			else:
				QMessageBox.warning(None, "Kumblr", "Could not log onto tumblr,\nhave you entered username/email/password correct?\n\n"+ self.tumblrAuth)
			print self.tumblr.auth()
		
	def changeType(self, a):
		self.type = str(a).lower() 
		print a
		if str(a).lower() == "regular":
		    self.quoteWidget.hide()
		    self.linkWidget.hide()
		    self.regularWidget.show()
#		    self.title.setFocus()
		elif str(a).lower() == "quote":
		    self.regularWidget.hide()
		    self.linkWidget.hide()
		    self.quoteWidget.show()
#		    self.quote.setFocus()
		elif str(a).lower() == "link":
		    self.regularWidget.hide()
		    self.quoteWidget.hide()
		    self.linkWidget.show()
#		    self.linkName.setFocus()
		    
	def changeAccount(self):
		self.setupAccountDialog.hide()
		settings = QSettings("Kumblr", "Kumblr")

		settings.beginGroup("Account")
		settings.setValue("username", QVariant(self.usernameTextBox.text()))
		settings.setValue("email", QVariant(self.emailTextBox.text()))
		settings.setValue("password", QVariant(self.passTextBox.text()))
		settings.endGroup()
		
		self.setupTumblr()
		    
	def setupAccount(self):
		self.setupAccountDialog = QDialog()
		self.setupAccountDialog.setModal(True)
		
		layout = QGridLayout()

		userLabel =QLabel(self.tr("Username"))
		self.usernameTextBox= QLineEdit()
		emailLabel =QLabel(self.tr("Email"))
		self.emailTextBox= QLineEdit()
		passLabel = QLabel(self.tr("Password"))
		self.passTextBox = QLineEdit()
		self.passTextBox.setEchoMode(QLineEdit.Password)
		submit = QPushButton(self.tr("Change account"))
		QObject.connect(submit, SIGNAL("released()"), self.changeAccount)
		
		settings = QSettings("Kumblr", "Kumblr")
		settings.beginGroup("Account")
		self.username = settings.value("username").toString()
		self.email = settings.value("email").toString()
		self.password = settings.value("password").toString()
		
		self.usernameTextBox.setText(self.username)
		self.emailTextBox.setText(self.email)
		self.passTextBox.setText(self.password)

		layout.addWidget(userLabel, 0, 0)
		layout.addWidget(self.usernameTextBox, 0, 1)
		layout.addWidget(emailLabel, 1, 0)
		layout.addWidget(self.emailTextBox, 1, 1)
		layout.addWidget(passLabel, 2,  0)
		layout.addWidget(self.passTextBox, 2, 1)
		
		layout.addWidget(submit, 4, 1)
		
		self.setupAccountDialog.setLayout(layout)
		
		self.setupAccountDialog.show()

	def setupUi(self):
		self.window = QMainWindow()
		self.window.setWindowTitle("Kumblr")
		
		self.main = QWidget()
		
		self.fileMenu = QMenu("File")
		self.menu = QMenuBar()
		self.menu.addMenu(self.fileMenu)
		self.fileMenu.addAction("Edit account",  self.setupAccount)
		
		self.window.setCentralWidget(self.main)
		self.window.setMenuBar(self.menu)
		
		self.layout = QVBoxLayout()
		self.main.setLayout(self.layout)
		
		self.chooseType = QComboBox()
		self.chooseType.addItem("Regular")
		self.chooseType.addItem("Quote")
		self.chooseType.addItem("Link")
		self.type = "regular"
		
		self.regularWidget = QWidget()
		self.regularLayout = QVBoxLayout()
		self.regularWidget.setLayout(self.regularLayout)
		self.title = QLineEdit()
		self.textArea = QTextEdit()
		self.textArea.setTabChangesFocus(True)
		self.regularLayout.addWidget(QLabel("Title"))
		self.regularLayout.addWidget(self.title)
		self.regularLayout.addWidget(QLabel("Body"))
		self.regularLayout.addWidget(self.textArea)
		
		self.quoteWidget = QWidget()
		self.quoteLayout = QVBoxLayout()
		self.quoteWidget.setLayout(self.quoteLayout)
		self.quote = QTextEdit()
		self.quote.setTabChangesFocus(True)
		self.source = QTextEdit()
		self.source.setTabChangesFocus(True)
		self.quoteLayout.addWidget(QLabel("Quote"))
		self.quoteLayout.addWidget(self.quote)
		self.quoteLayout.addWidget(QLabel("Source (opt)"))
		self.quoteLayout.addWidget(self.source)
		self.quoteWidget.hide()
		
		self.linkWidget = QWidget()
		self.linkLayout = QVBoxLayout()
		self.linkWidget.setLayout(self.linkLayout)
		self.linkName= QLineEdit()
		self.linkUrl = QLineEdit()
		self.linkDesc = QTextEdit()
		self.linkDesc.setTabChangesFocus(True)
		self.linkLayout.addWidget(QLabel("Name"))
		self.linkLayout.addWidget(self.linkName)
		self.linkLayout.addWidget(QLabel("Url"))
		self.linkLayout.addWidget(self.linkUrl)
		self.linkLayout.addWidget(QLabel("Desc (opt)"))
		self.linkLayout.addWidget(self.linkDesc)
		self.linkLayout.addStretch()
		self.linkWidget.hide()
		
		self.submit = QPushButton(self.tr("Submit"))
		
		self.layout.addWidget(self.chooseType)
		self.layout.addWidget(self.regularWidget)
		self.layout.addWidget(self.quoteWidget)
		self.layout.addWidget(self.linkWidget)
		
		self.layout.addWidget(self.submit)
		
		QObject.connect(self.submit, SIGNAL("released()"), self.post)
		QObject.connect(self.chooseType, SIGNAL("currentIndexChanged(QString)"), self.changeType)
		
		self.trayIconMenu = QMenu()

		self.trayIcon = QSystemTrayIcon(QIcon(":/tumblr_icon.png"),  self);
		self.trayIcon.setToolTip("Kumblr - Tumble away!")
		self.trayIcon.setContextMenu(self.trayIconMenu);
		
		self.quitAction = QAction(self.tr("Quit"), self)
		QObject.connect(self.quitAction, SIGNAL("triggered()"), self.quit)
		self.trayIconMenu.addAction(self.quitAction)
		
		self.trayIcon.setContextMenu(self.trayIconMenu);

		QObject.connect(self.trayIcon, SIGNAL("activated(QSystemTrayIcon::ActivationReason)"), self.activated)
#		QObject.connect(self.trayIcon, SIGNAL("messageClicked()"), self.balloonClicked)
		self.trayIcon.show()

		self.window.show()
		
	def toggleVisibility(self):
		if self.window.isVisible():
			self.window.hide()
		else:
			self.window.show()
			self.window.showNormal()
		
	def balloonClicked(self):
		print "a"

	def activated(self, a):
		if a == QSystemTrayIcon.Trigger:
			self.toggleVisibility()

	def post(self):
		self.submit.setDisabled(True)
		if self.type == "regular":
			self.tumblrTitle = self.title.text().toUtf8()
			self.tumblrBody = self.textArea.toPlainText().toUtf8()
			self.tumblrResult = self.tumblr.blogwrite(type=self.type, t=self.tumblrTitle , b=self.tumblrBody)
		elif self.type == "quote":
			self.tumblrTitle = self.quote.toPlainText().toUtf8()
			self.tumblrBody = self.source.toPlainText().toUtf8()
			self.tumblrResult = self.tumblr.blogwrite(type=self.type, q=self.tumblrTitle , s=self.tumblrBody)
		elif self.type == "link":
			self.tumblrTitle = self.linkName.text().toUtf8()
			self.tumblrBody = self.linkUrl.text().toUtf8()
			self.tumblrDesc = self.linkDesc.toPlainText().toUtf8()
			self.tumblrResult = self.tumblr.blogwrite(type=self.type, n=self.tumblrTitle , u=self.tumblrBody,  d=self.tumblrDesc)
		if self.tumblrResult ==  'Success':
			if self.type == "regular":
				self.title.setText('')
				self.textArea.setText('')
				self.title.setFocus
			elif self.type == "quote":
				self.quote.setText('')
				self.source.setText('')
				self.quote.setFocus
			elif self.type == "link":
				self.linkName.setText('')
				self.linkUrl.setText('')
				self.linkDesc.setText('')
				self.linkName.setFocus
		else:
			print self.tumblrResult 
			QMessageBox.warning(None, "Kumblr", "Roadkill!\n Can't post, check your connection")
		self.submit.setEnabled(True)
		
if __name__ == "__main__":

	app = App(sys.argv)
	sys.exit(app.exec_())
	
